# CHANGELOG

### 0.1.6 - 2024-09-28
- Used `prettytable` for benchmark output (`cythonpowered --benchmark`) 

### 0.1.5 - 2024-09-23
- Bugfix in setup

### 0.1.4 - 2024-09-23
- Added the `cythonpowered` CLI script as an entrypoint for all utils and scripts
- Deprecated the `cythonpowered-benchmark` script

### 0.1.3 - 2024-09-22
- Bugfix in Cython preinstallation

### 0.1.2 - 2024-09-22
- Added MANIFEST.in
- Ensured markdown project description

### 0.1.1 - 2024-09-22
- Bugfix in setup

### 0.1.0 - 2024-09-22
- Added the `cythonpowered-benchmark` script
- Development updates

### 0.0.3 - 2024-09-10
- Update requirements

### 0.0.2 - 2024-09-10
- Bugfix in setup

### 0.0.1 - 2024-09-10
- First release
- Includes the `cythonpowered.random` module
